import _ from 'lodash';
import { useCallback } from 'react';
import { getDefaultValue } from "../../definition/defaultValue";
import { addRef } from "../../utils/utils";

/**
 * [业务]返回 array 创建新项的函数，调用后会直接在 array 后面创建正确的新数组项内容。
 * @param ctx
 * @param data
 * @param access
 * @param arraySchema
 * @returns
 */
export var useArrayCreator = function useArrayCreator(ctx, data, access, arraySchema, schemaEntry) {
  return useCallback(function () {
    var _ref = arraySchema || {},
      maxItems = _ref.maxItems,
      items = _ref.items,
      prefixItems = _ref.prefixItems;
    // 数组新变量创建。注意如果使用已有变量直接创建时不要忘记深拷贝！
    var nowLength = data.length;
    if (!maxItems || nowLength < maxItems) {
      if (prefixItems) {
        // 存在前缀约束的情况
        var prefixLength = prefixItems.length,
          ref = prefixItems.ref;
        if (nowLength < prefixLength) {
          // 新项处于 prefixItems 约束的位置时，通过对应 items 约束得到 defaultValue
          var defaultValue = getDefaultValue(ctx, addRef(ref, nowLength.toString()));
          ctx.executeAction('create', {
            schemaEntry: schemaEntry,
            route: access,
            field: nowLength.toString(),
            value: defaultValue
          });
        } else if (nowLength === prefixLength && items) {
          // 如果新建项恰好不属于 prefixItems，而且 additional 允许建且有约束，使用这个约束
          var _defaultValue = getDefaultValue(ctx, items);
          ctx.executeAction('create', {
            schemaEntry: schemaEntry,
            route: access,
            field: nowLength.toString(),
            value: _defaultValue
          });
        }
      } else if (data.length > 0) {
        // 此外如果有上一项(默认符合 schema)，copy 上一项
        ctx.executeAction('create', {
          schemaEntry: schemaEntry,
          route: access,
          field: nowLength.toString(),
          value: _.cloneDeep(data[data.length - 1])
        });
      } else {
        // 有 items 约束，使用 items 默认值，否则 null
        ctx.executeAction('create', {
          schemaEntry: schemaEntry,
          route: access,
          field: nowLength.toString(),
          value: items ? getDefaultValue(ctx, items) : null
        });
      }
    }
  }, [data, arraySchema, access, ctx]);
};