function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import range from 'lodash/range';
import { useMemo } from 'react';
import { isShort } from "../../context/virtual";
import { canFieldCreate } from "../../definition/schema";
import { addRef } from "../../utils/utils";
/**
 * [业务] 给出数组数据的两表渲染参数。
 *
 * 注：
 *
 * - 该函数输出短等级不一致的，最多两个列表。
 * - 如果可以创建新的列表项，最后一个列表的最后一项为`null`
 * @param data
 * @param schemaEntry
 * @param fieldInfo
 * @returns
 */
export var useArrayListContent = function useArrayListContent(ctx, data, schemaEntry, fieldInfo) {
  var valueEntry = fieldInfo.valueEntry,
    mergedValueSchema = fieldInfo.mergedValueSchema;
  var _ref = mergedValueSchema || {},
    _ref$prefixItems = _ref.prefixItems,
    _ref$prefixItems2 = _ref$prefixItems === void 0 ? {} : _ref$prefixItems,
    _ref$prefixItems2$len = _ref$prefixItems2.length,
    prefixLength = _ref$prefixItems2$len === void 0 ? undefined : _ref$prefixItems2$len,
    _ref$prefixItems2$ref = _ref$prefixItems2.ref,
    prefixRef = _ref$prefixItems2$ref === void 0 ? '' : _ref$prefixItems2$ref,
    items = _ref.items;
  return useMemo(function () {
    var prefixList = [];
    var itemsList = [];

    // 分别确定两个表的短字段等级
    var prefixIsShort = prefixLength ? Math.min.apply(Math, _toConsumableArray(range(prefixLength).map(function (i) {
      var _ref2 = ctx.getMergedSchema(addRef(prefixRef, i.toString())) || {},
        shortable = _ref2[isShort],
        title = _ref2.title;
      return shortable ? title ? 1 : 2 : 0;
    }))) : 0;
    var _ref3 = items ? ctx.getMergedSchema(items) || {} : {},
      _ref3$isShort = _ref3[isShort],
      itemsShortable = _ref3$isShort === void 0 ? false : _ref3$isShort,
      _ref3$title = _ref3.title,
      title = _ref3$title === void 0 ? undefined : _ref3$title;
    var listShortLevel = [prefixIsShort, itemsShortable ? title ? 1 : 2 : 0];

    // 如果前缀和余项的短字段等级不同，按照项是否为前缀项，分到两个表中
    if (listShortLevel[0] !== listShortLevel[1] && prefixLength !== undefined) {
      var prefixListLength = Math.min(prefixLength, data.length);
      for (var i = 0; i < prefixListLength; i++) {
        prefixList.push({
          key: i.toString(),
          value: data[i]
        });
      }
    }
    for (var _i = prefixLength !== null && prefixLength !== void 0 ? prefixLength : 0; _i < data.length; _i++) {
      itemsList.push({
        key: _i.toString(),
        value: data[_i]
      });
    }

    // 如果可以创建新项，在第二个表后面加入 { key: '' }，代表该项为 create 组件
    var canCreate = canFieldCreate(data, fieldInfo);
    if (canCreate) itemsList.push({
      key: ''
    });
    return [prefixList, itemsList].map(function (propList, i) {
      return {
        short: listShortLevel[i],
        items: propList
      };
    }).filter(function (list) {
      return list.items.length > 0;
    });
  }, [schemaEntry, valueEntry, data, ctx]);
};