import React, { useEffect, useMemo } from 'react';
import { canFieldRename } from "../../definition/schema";
import { concatAccess, getFieldDomId, jsonDataType } from "../../utils/utils";
import { ComponentModel } from "../ComponentModel";

/**
 * [业务] 将 componentModel 挂载到 ctx.interaction
 * @param ctx
 * @param route
 * @param field
 * @param viewport
 * @param model
 * @returns
 */
export var useContainer = function useContainer(ctx, fieldProps, fieldInfo) {
  var data = fieldProps.data,
    viewport = fieldProps.viewport,
    route = fieldProps.route,
    field = fieldProps.field;
  var mergedValueSchema = fieldInfo.mergedValueSchema,
    mergedEntrySchema = fieldInfo.mergedEntrySchema;
  var _ref = mergedValueSchema || {},
    constValue = _ref.const,
    enumValue = _ref.enum,
    _ref$view = _ref.view,
    _ref$view2 = _ref$view === void 0 ? {} : _ref$view,
    _ref$view2$type = _ref$view2.type,
    valueEntryViewType = _ref$view2$type === void 0 ? undefined : _ref$view2$type;
  var dataType = jsonDataType(data);
  var valueType = constValue !== undefined ? 'const' : enumValue !== undefined ? 'enum' : dataType;
  var id = getFieldDomId(viewport, concatAccess(route, field));
  var _ref2 = mergedValueSchema || {},
    format = _ref2.format;
  var _ref3 = mergedEntrySchema || {},
    _ref3$view = _ref3.view,
    _ref3$view2 = _ref3$view === void 0 ? {} : _ref3$view,
    _ref3$view2$type = _ref3$view2.type,
    schemaEntryViewType = _ref3$view2$type === void 0 ? null : _ref3$view2$type;
  var fieldNameRange = canFieldRename(ctx, fieldProps, fieldInfo);

  // 1. 设置标题组件
  var TitleComponent = ctx.getComponent(schemaEntryViewType, ['title']);

  // 2. 设置值组件
  var EditionComponent = valueType === 'string' && format ? ctx.getFormatComponent(valueEntryViewType, format) : ctx.getComponent(valueEntryViewType, ['edition', valueType]);
  var editionInfo = {
    valueType: valueType,
    viewType: valueEntryViewType,
    format: format
  };
  var model = useMemo(function () {
    return new ComponentModel();
  }, []);
  useEffect(function () {
    ctx.interaction.componentModelMap.set(id, model);
    return function () {
      ctx.interaction.componentModelMap.delete(id);
    };
  }, [ctx]);
  return {
    titleElement: /*#__PURE__*/React.createElement(TitleComponent, {
      fieldNameRange: fieldNameRange,
      fieldProps: fieldProps,
      ctx: ctx,
      fieldInfo: fieldInfo,
      key: 'title',
      model: model
    }),
    editionElement: /*#__PURE__*/React.createElement(EditionComponent, {
      fieldProps: fieldProps,
      ctx: ctx,
      fieldInfo: fieldInfo,
      key: 'edition',
      model: model
    }),
    editionInfo: editionInfo,
    model: model,
    fieldNameRange: fieldNameRange,
    id: id
  };
};