import React from 'react';
import { getRefByOfChain } from "../../context/ofInfo";
import { defaultTypeValue, getDefaultValue } from "../../definition/defaultValue";
import { JsonTypes } from "../../definition/reducer";
import { jsonDataType } from "../../utils/utils";
/**
 * [业务]通过 Field 的属性得到使用的 菜单栏 和 操作栏 组件
 * @param props
 */
export var useMenuActionComponents = function useMenuActionComponents(props, model) {
  var _props$fieldProps = props.fieldProps,
    data = _props$fieldProps.data,
    route = _props$fieldProps.route,
    field = _props$fieldProps.field,
    schemaEntry = _props$fieldProps.schemaEntry,
    fieldInfo = props.fieldInfo,
    availableMenuActions = props.availableMenuActions,
    menuActionHandlers = props.menuActionHandlers,
    ctx = props.ctx;
  var mergedValueSchema = fieldInfo.mergedValueSchema,
    ofOption = fieldInfo.ofOption,
    id = fieldInfo.id;
  var dataType = jsonDataType(data);
  var _ref = mergedValueSchema || {},
    constValue = _ref.const,
    enumValue = _ref.enum,
    allowedTypes = _ref.type;
  var valueType = constValue !== undefined ? 'const' : enumValue !== undefined ? 'enum' : dataType;
  var directActionComs = [];
  // a. 如果存在 oneOfOption，加入 oneOf 调整组件
  if (schemaEntry && ofOption !== null) {
    var ofInfo = ctx.getOfInfo(schemaEntry);
    var OneOfOperation = ctx.getComponent(null, ['operation', 'oneOf']);
    directActionComs.push( /*#__PURE__*/React.createElement(OneOfOperation, {
      opValue: ofOption ? ofOption : '',
      opParam: ofInfo,
      opHandler: function opHandler(value) {
        var schemaRef = getRefByOfChain(ctx, schemaEntry, value);
        var defaultValue = getDefaultValue(ctx, schemaRef, data);
        ctx.executeAction('change', {
          route: route,
          field: field,
          value: defaultValue,
          schemaEntry: schemaEntry
        });
      },
      key: 'oneOf',
      ctx: ctx,
      id: id,
      model: model
    }));
  }

  // b. 如果不是 const/enum，且允许多种 type，加入 type 调整组件
  if (valueType !== 'const' && valueType !== 'enum' && (mergedValueSchema === false || !allowedTypes || allowedTypes.length !== 1)) {
    var typeOptions = allowedTypes && allowedTypes.length > 0 ? allowedTypes : JsonTypes;
    var TypeOperation = ctx.getComponent(null, ['operation', 'type']);
    directActionComs.push( /*#__PURE__*/React.createElement(TypeOperation, {
      opValue: dataType,
      opParam: typeOptions,
      opHandler: function opHandler(value) {
        ctx.executeAction('change', {
          route: route,
          field: field,
          value: defaultTypeValue[value],
          schemaEntry: schemaEntry
        });
      },
      key: 'type',
      ctx: ctx,
      id: id,
      model: model
    }));
  }
  // 4. 设置菜单动作栏组件
  var menuActionComs = availableMenuActions.map(function (actType) {
    var MenuActionComponent = ctx.getComponent(null, ['menuAction']);
    return /*#__PURE__*/React.createElement(MenuActionComponent, {
      key: actType,
      opType: actType,
      opHandler: menuActionHandlers[actType],
      ctx: ctx,
      id: id,
      model: model
    });
  });
  return [directActionComs, menuActionComs];
};