import { useCallback, useMemo } from 'react';
import { getDefaultValue } from "../../definition/defaultValue";
/**
 * [业务] 获取所有 menuAction 的处理函数
 * @param ctx
 * @param route
 * @param field
 * @param valueEntry
 * @param data
 * @returns
 */
export var useMenuActionHandlers = function useMenuActionHandlers(ctx, route, field, fatherInfo, schemaEntry, valueEntry, data) {
  var _ref = fatherInfo !== null && fatherInfo !== void 0 ? fatherInfo : {},
    parentSchemaEntry = _ref.schemaEntry;
  var resetHandler = useCallback(function () {
    ctx.executeAction('change', {
      route: route,
      field: field,
      value: getDefaultValue(ctx, valueEntry, data)
    });
  }, [data, valueEntry, route, field, ctx]);
  var menuActionHandlers = useMemo(function () {
    return {
      detail: function detail() {
        ctx.interaction.setDrawer(route, field);
      },
      reset: resetHandler,
      moveup: function moveup() {
        ctx.executeAction('moveup', {
          route: route,
          field: field,
          schemaEntry: parentSchemaEntry
        });
      },
      movedown: function movedown() {
        ctx.executeAction('movedown', {
          route: route,
          field: field,
          schemaEntry: parentSchemaEntry
        });
      },
      delete: function _delete() {
        ctx.executeAction('delete', {
          route: route,
          field: field,
          schemaEntry: parentSchemaEntry
        });
      },
      undo: function undo() {
        ctx.executeAction('undo');
      },
      redo: function redo() {
        ctx.executeAction('redo');
      },
      paste: function paste() {
        ctx.executeAction('change', {
          route: route,
          field: field,
          value: 0,
          schemaEntry: schemaEntry
        });
      }
    };
  }, [resetHandler, route, field, ctx, parentSchemaEntry]);
  return menuActionHandlers;
};