import { useCallback } from 'react';
import { getDefaultValue } from "../../definition/defaultValue";
import { getValueByPattern } from "../../utils/utils";

/**
 * [业务]返回 object 创建新项的函数，传入新属性名称调用，会直接创建正确的新属性内容。
 * @param ctx
 * @param data
 * @param access
 * @param schemaEntry
 * @param objectSchema
 * @returns `string`: 不能创建的原因; `CpuEditorAction`：代表正确创建，返回创建的`action`
 */
export var useObjectCreator = function useObjectCreator(ctx, data, access, schemaEntry, objectSchema) {
  return useCallback(function (newPropName) {
    var _ref = objectSchema || {},
      properties = _ref.properties,
      patternProperties = _ref.patternProperties,
      additionalProperties = _ref.additionalProperties;
    var newValueEntry = undefined;
    if (data[newPropName] !== undefined) {
      return "\u5B57\u6BB5 ".concat(newPropName, " \u5DF2\u7ECF\u5B58\u5728\uFF01");
    } else {
      var _ref2;
      var newPropRef = (_ref2 = properties && properties[newPropName]) !== null && _ref2 !== void 0 ? _ref2 : patternProperties && getValueByPattern(patternProperties, newPropName);
      if (!newPropRef) {
        if (additionalProperties !== false) {
          newValueEntry = additionalProperties;
        } else {
          return "".concat(newPropName, " \u4E0D\u5339\u914D properties \u4E2D\u7684\u540D\u79F0\u6216 patternProperties \u4E2D\u7684\u6B63\u5219\u5F0F");
        }
      } else {
        newValueEntry = newPropRef;
      }
    }
    return ctx.executeAction('create', {
      route: access,
      field: newPropName,
      value: getDefaultValue(ctx, newValueEntry),
      schemaEntry: schemaEntry
    });
  }, [data, objectSchema, access, ctx]);
};