import { useMemo } from 'react';
import { isShort } from "../../context/virtual";
import { ShortLevel } from "../../definition/definitions";
import { canFieldCreate } from "../../definition/schema";
import { getValueByPattern } from "../../utils/utils";
/**
 * [业务] 给出对象数据的两表渲染参数。
 *
 * 注：
 *
 * - 该函数输出短等级不一致的，最多两个列表。
 * - 如果可以创建新的列表项，最后一个列表的最后一项为`null`
 * @param data
 * @param schemaEntry
 * @param fieldInfo
 * @returns
 */
export var useObjectListContent = function useObjectListContent(ctx, data, schemaEntry, fieldInfo) {
  var valueEntry = fieldInfo.valueEntry,
    mergedValueSchema = fieldInfo.mergedValueSchema;
  var _ref = mergedValueSchema || {},
    properties = _ref.properties,
    additionalProperties = _ref.additionalProperties,
    patternProperties = _ref.patternProperties;
  return useMemo(function () {
    var shortenProps = [];
    var normalProps = [];

    // 短表在前，长表在后
    var listShortLevel = [ShortLevel.short, ShortLevel.no];

    // 按照属性是否是短字段分到两个表中
    for (var key in data) {
      if (Object.prototype.hasOwnProperty.call(data, key)) {
        var value = data[key];
        var patternRef = patternProperties ? getValueByPattern(patternProperties, key) : undefined;
        var propRealRef = properties && properties[key] ? properties[key] : patternRef ? patternRef : additionalProperties;
        if (propRealRef) {
          var _ref2 = ctx.getMergedSchema(propRealRef) || {},
            shortable = _ref2[isShort];
          if (shortable) {
            shortenProps.push({
              key: key,
              value: data[key]
            });
            continue;
          }
        }
        normalProps.push({
          key: key,
          value: value
        });
      }
    }

    // 如果可以创建新项，在第二个表后面加入 null，代表该项为 create 组件
    var canCreate = canFieldCreate(data, fieldInfo);
    if (canCreate) normalProps.push({
      key: ''
    });
    return [shortenProps, normalProps].map(function (propList, i) {
      return {
        short: listShortLevel[i],
        items: propList
      };
    }).filter(function (list) {
      return list.items.length > 0;
    });
  }, [schemaEntry, valueEntry, data, ctx]);
};