import Ajv from 'ajv/dist/core';
import { ComponentType } from 'react';
import { AnyAction, Dispatch, Store } from 'redux';
import { StateWithHistory } from 'redux-undo';
import { IComponentMap, IViewsMap } from '../components/ComponentMap';
import { CpuEditorActionOption, CpuEditorState } from '../definition/reducer';
import { JSONSchema } from '../type/Schema';
import { CpuInteraction } from './interaction';
import { MergedSchema } from './mergeSchema';
import { ofSchemaCache } from './ofInfo';
import { CpuResources } from './resources';
export interface SchemaArrayRefInfo {
    ref: string;
    length: number;
}
/**
 * 整个`editor`的上下文，包含了：
 * - redux store
 * - `schema`的各个`ref`对应的模式性质信息
 * 在编辑器`schema`变更时重新初始化
 */
export declare class CpuEditorContext {
    ajvInstance: Ajv;
    domId: string | undefined;
    interaction: CpuInteraction;
    resources: CpuResources;
    readonly componentMap: IComponentMap<any>;
    /**
     * 自定义 view 的组件列表，通过`view.type`索引到 componentMap；
     *
     * 其中 componentMap 的组件都是非必须的。
     *
     * 如果在 schema 中限定了`view.type`，但没有在对应的 componentMap 找到组件，将使用对应的默认组件代替。
     */
    readonly viewsMap: Record<string, IViewsMap>;
    Field: import("react-redux").ConnectedComponent<import("react").MemoExoticComponent<(props: import("../Field").FieldProps) => JSX.Element>, {
        viewport: string;
        short?: import("..").ShortLevel | undefined;
        schemaEntry?: string | undefined;
        field?: string | undefined;
        route: string[];
        fatherInfo?: import("..").FatherInfo | undefined;
        canNotRename?: boolean | undefined;
        rootMenuItems?: JSX.Element[] | undefined;
        reRender?: any;
        data?: any;
        context?: import("react").Context<import("react-redux").ReactReduxContextValue<any, AnyAction>> | undefined;
        store?: Store<any, AnyAction> | undefined;
    }>;
    /**
     * 获取 store 中目前的 data
     * @returns
     */
    getNowData: () => any;
    rootSchema: JSONSchema | false;
    schemaId: string;
    schemaError: any;
    store: Store<StateWithHistory<CpuEditorState>, AnyAction>;
    basicModelMap: Map<string, any> | any;
    mergedSchemaMap: Map<string, MergedSchema | false>;
    /**
     * schemaInfo 是 schema 信息的需要对子层进行归纳的部分。
     * 将 schemaInfo 和 mergedSchema 分开，是为了编辑器可以按需创建这些信息。
     */
    ofInfoMap: Map<string, ofSchemaCache | null>;
    /**
     * 已加载资源的缓存列表，通过`url`为键索引。
     */
    resourceMap: Map<string, any>;
    dispatch: Dispatch<AnyAction>;
    private createAction;
    constructor(data: any, schema: boolean | JSONSchema | undefined, ajvInstance: Ajv, domId: string | undefined, interaction: CpuInteraction, resources: CpuResources, componentMap: IComponentMap<any>, 
    /**
     * 自定义 view 的组件列表，通过`view.type`索引到 componentMap；
     *
     * 其中 componentMap 的组件都是非必须的。
     *
     * 如果在 schema 中限定了`view.type`，但没有在对应的 componentMap 找到组件，将使用对应的默认组件代替。
     */
    viewsMap: Record<string, IViewsMap>);
    /**
     * 直接执行动作，对数据进行操作
     * @param type
     * @param options
     * @returns
     */
    executeAction(type: string, options?: CpuEditorActionOption): import("../definition/reducer").CpuEditorAction;
    /**
     * 得到对应 ref 的合并的模式。
     * 如果 ref 不存在则返回空对象
     * @param ref
     * @returns
     */
    getMergedSchema(ref: string | undefined): false | MergedSchema;
    /**
     * 得到 ref 对应模式的 of 信息。
     *
     * @param ref
     * @returns
     */
    getOfInfo(ref: string | undefined): ofSchemaCache | null;
    /**
     * 从 componentMap 找到对应 role path 的组件。
     *
     * 和`getComponent`的区别是，若未找到，会 fallback 为对应的`string`编辑组件。
     * @param view 组件的`viewType`(必须经过验证)
     * @param rolePath 组件角色路径
     * @returns
     */
    getComponent(view: string | null | undefined, rolePath: string | string[]): ComponentType<any>;
    /**
     * 从 componentMap 找到对应 string format 的组件。
     *
     * 和`getComponent`的区别是，若未找到，会 fallback 为对应的`string`编辑组件。
     * @param view 组件的`viewType`(必须经过验证)
     * @param format
     * @returns
     */
    getFormatComponent(view: string | null | undefined, format: string): ComponentType<any>;
    private makeMergedSchema;
}
