function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import { createStore } from 'redux';
import { v4 as uuidv4 } from 'uuid';
import { doAction, getReducer } from "../definition/reducer";
import { Field } from "../Field";
import { getRefSchemaMap } from "../utils/schemaWithRef";
import { deepGet } from "../utils/utils";
import { mergeSchemaMap } from "./mergeSchema";
import { setOfInfo } from "./ofInfo";
/**
 * 整个`editor`的上下文，包含了：
 * - redux store
 * - `schema`的各个`ref`对应的模式性质信息
 * 在编辑器`schema`变更时重新初始化
 */
export var CpuEditorContext = /*#__PURE__*/function () {
  /**
   * 获取 store 中目前的 data
   * @returns
   */

  /**
   * schemaInfo 是 schema 信息的需要对子层进行归纳的部分。
   * 将 schemaInfo 和 mergedSchema 分开，是为了编辑器可以按需创建这些信息。
   */

  /**
   * 已加载资源的缓存列表，通过`url`为键索引。
   */

  function CpuEditorContext(data, schema, ajvInstance, domId, interaction, resources, componentMap,
  /**
   * 自定义 view 的组件列表，通过`view.type`索引到 componentMap；
   *
   * 其中 componentMap 的组件都是非必须的。
   *
   * 如果在 schema 中限定了`view.type`，但没有在对应的 componentMap 找到组件，将使用对应的默认组件代替。
   */
  viewsMap) {
    var _this = this;
    _classCallCheck(this, CpuEditorContext);
    _defineProperty(this, "Field", Field);
    _defineProperty(this, "getNowData", function () {
      return _this.store.getState().present.data;
    });
    _defineProperty(this, "rootSchema", void 0);
    _defineProperty(this, "schemaId", void 0);
    _defineProperty(this, "schemaError", void 0);
    _defineProperty(this, "store", void 0);
    _defineProperty(this, "basicModelMap", void 0);
    _defineProperty(this, "mergedSchemaMap", void 0);
    _defineProperty(this, "ofInfoMap", void 0);
    _defineProperty(this, "resourceMap", void 0);
    _defineProperty(this, "dispatch", void 0);
    _defineProperty(this, "createAction", void 0);
    this.ajvInstance = ajvInstance;
    this.domId = domId;
    this.interaction = interaction;
    this.resources = resources;
    this.componentMap = componentMap;
    this.viewsMap = viewsMap;
    // 1. 注册 schema，并设立 id
    try {
      var realSchema = schema === true ? {} : schema ? schema : schema === false ? false : {};
      var idInSchema = realSchema ? realSchema.$id || realSchema.id : undefined;
      this.schemaId = idInSchema || uuidv4();
      ajvInstance.addSchema(realSchema, this.schemaId);
      this.rootSchema = realSchema;
    } catch (error) {
      this.schemaError = error;
      // 出错了，注册一个空 schema
      this.schemaId = uuidv4();
      this.rootSchema = {};
      ajvInstance.addSchema(this.rootSchema, this.schemaId);
    }

    // 2. 初始化 store，拿到 dispatch
    var initialState = {
      data: data,
      dataErrors: {}
    };
    this.store = createStore(getReducer(this), {
      past: [],
      present: initialState,
      future: []
    });
    this.dispatch = this.store.dispatch;
    this.createAction = doAction;
    // 3. 初始化各种 map
    this.mergedSchemaMap = new Map();
    this.ofInfoMap = new Map();
    this.resourceMap = new Map();
  }

  /**
   * 直接执行动作，对数据进行操作
   * @param type
   * @param options
   * @returns
   */
  _createClass(CpuEditorContext, [{
    key: "executeAction",
    value: function executeAction(type) {
      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var action = this.createAction(type, options);
      this.dispatch(action);
      return action;
    }

    /**
     * 得到对应 ref 的合并的模式。
     * 如果 ref 不存在则返回空对象
     * @param ref
     * @returns
     */
  }, {
    key: "getMergedSchema",
    value: function getMergedSchema(ref) {
      if (this.rootSchema === false || !ref) return false;
      return this.mergedSchemaMap.has(ref) ? this.mergedSchemaMap.get(ref) : this.makeMergedSchema(ref);
    }

    /**
     * 得到 ref 对应模式的 of 信息。
     *
     * @param ref
     * @returns
     */
  }, {
    key: "getOfInfo",
    value: function getOfInfo(ref) {
      if (this.rootSchema === false || !ref) return null;
      return this.ofInfoMap.has(ref) ? this.ofInfoMap.get(ref) : setOfInfo(this, ref, this.rootSchema);
    }

    /**
     * 从 componentMap 找到对应 role path 的组件。
     *
     * 和`getComponent`的区别是，若未找到，会 fallback 为对应的`string`编辑组件。
     * @param view 组件的`viewType`(必须经过验证)
     * @param rolePath 组件角色路径
     * @returns
     */
  }, {
    key: "getComponent",
    value: function getComponent() {
      var view = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
      var rolePath = arguments.length > 1 ? arguments[1] : undefined;
      var componentPath = typeof rolePath === 'string' ? [rolePath] : rolePath;
      if (view) {
        var _result = deepGet(this.viewsMap[view] || {}, componentPath);
        if (_result) return _result;
      }
      var result = deepGet(this.componentMap, componentPath);
      if (result) {
        return result;
      } else {
        throw new Error("The component of ".concat(componentPath, " not exist in component map"));
      }
    }

    /**
     * 从 componentMap 找到对应 string format 的组件。
     *
     * 和`getComponent`的区别是，若未找到，会 fallback 为对应的`string`编辑组件。
     * @param view 组件的`viewType`(必须经过验证)
     * @param format
     * @returns
     */
  }, {
    key: "getFormatComponent",
    value: function getFormatComponent() {
      var view = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
      var format = arguments.length > 1 ? arguments[1] : undefined;
      var componentPath = ['format', format];
      if (view) {
        var _result2 = deepGet(this.viewsMap, componentPath);
        if (_result2) return _result2;
      }
      var result = deepGet(this.componentMap, componentPath);
      if (result) {
        return result;
      } else {
        return this.getComponent(view, ['edition', 'string']);
      }
    }
  }, {
    key: "makeMergedSchema",
    value: function makeMergedSchema(ref) {
      if (typeof this.rootSchema === 'boolean') return false;
      var map = getRefSchemaMap(ref, this.rootSchema);
      var mergedSchema = mergeSchemaMap(this, map);
      this.mergedSchemaMap.set(ref, mergedSchema);
      return mergedSchema;
    }
  }]);
  return CpuEditorContext;
}();