import { getFormatType } from "../definition/formats";
// symbols
export var isShort = Symbol.for('short');

// all virtual props

/**
 * 确定schema是否可以短优化。条件：
 * 1. 类型确定且为string/number/bool/null，且没有oneof
 * 2. 有enum
 * 注：由于目前该函数主要从 valueInfo 确定子属性时调用，所以不必缓存。
 * @param mergedSchema
 */
export var schemaIsShort = function schemaIsShort(ctx, mergedSchema) {
  var constValue = mergedSchema.const,
    enumValue = mergedSchema.enum,
    allowedTypes = mergedSchema.type,
    format = mergedSchema.format,
    _mergedSchema$view = mergedSchema.view,
    _mergedSchema$view2 = _mergedSchema$view === void 0 ? {} : _mergedSchema$view,
    viewType = _mergedSchema$view2.type;
  if (constValue !== undefined || enumValue) return true;
  if (allowedTypes && allowedTypes.length === 1) {
    if (viewType) {
      var _ref = ctx.viewsMap[viewType] || {},
        _ref$shortable = _ref.shortable,
        shortable = _ref$shortable === void 0 ? false : _ref$shortable;
      return shortable;
    }
    var type = allowedTypes[0];
    switch (type) {
      case 'string':
        if (format && getFormatType(format)) return false;
        return true;
      case 'number':
      case 'integer':
      case 'boolean':
      case 'null':
        return true;
      default:
        return false;
    }
  }
  return false;
};