function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
/* eslint-disable no-param-reassign */
/* eslint-disable no-case-declarations */
import { produce } from 'immer';
import _ from 'lodash';
import { addRef, getValueByPattern, jsonDataType } from "../utils/utils";

// defaultValue
export var defaultTypeValue = {
  string: '',
  number: 0,
  integer: 0,
  object: {},
  array: [],
  null: null,
  boolean: false
};

/**
 * 通过一个schemaEntry 得到schema，确定其创建时默认对象。
 * 允许找不到schema的场合，且前后变量保持最大兼容
 * @param ctx
 * @param entry 目标位置的 valueEntry，切换 of 选项的情况下不同于目前数据的 valueEntry，切换
 * @param nowData 目前的数据
 * @returns
 */
export var getDefaultValue = function getDefaultValue(ctx, entry) {
  var nowData = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : undefined;
  var mergedSchema = ctx.getMergedSchema(entry);
  if (!entry || !mergedSchema) return null;
  var properties = mergedSchema.properties,
    patternProperties = mergedSchema.patternProperties,
    required = mergedSchema.required,
    defaultValue = mergedSchema.default,
    constValue = mergedSchema.const,
    enumValue = mergedSchema.enum,
    allowedTypes = mergedSchema.type,
    prefixItems = mergedSchema.prefixItems,
    items = mergedSchema.items;
  var nowDataType = jsonDataType(nowData);
  // 0. 如果nowData是对象，且有属性列表，就先剪掉不在列表中的属性，然后进行合并
  if (nowDataType === 'object') {
    if (properties || patternProperties) {
      nowData = produce(nowData, function (draft) {
        for (var _i = 0, _Object$keys = Object.keys(draft); _i < _Object$keys.length; _i++) {
          var key = _Object$keys[_i];
          if ((!properties || !properties[key]) && (!patternProperties || !getValueByPattern(patternProperties, key))) delete draft[key];
        }
      });
    }
  }
  // 1. 优先返回规定的 default 字段值(注意深拷贝，否则会形成对象环！)
  if (defaultValue !== undefined) {
    var defaultType = jsonDataType(defaultValue);
    if (defaultType === 'object' && nowDataType === 'object') {
      // 特殊：如果默认是 object，会采取最大合并
      return Object.assign({}, nowData, _.cloneDeep(defaultValue));
    }
    return _.cloneDeep(defaultValue);
  } else {
    // 2. 如果有 const/enum，采用其值
    if (constValue !== undefined) return _.cloneDeep(constValue);
    if (enumValue !== undefined) return _.cloneDeep(enumValue[0]);
    // 3. oneOf/anyOf 选择第0项的schema返回
    var ofInfo = ctx.getOfInfo(entry);
    if (ofInfo) {
      return getDefaultValue(ctx, addRef(ofInfo.ofRef, '0'));
    }
  }
  // 4. 按照 schema 寻找答案
  if (allowedTypes && allowedTypes.length > 0) {
    var type = allowedTypes[0];
    switch (type) {
      case 'object':
        var result = jsonDataType(nowData) === 'object' ? _.clone(nowData) : {};
        if (required) {
          // 仅对 required 中的属性进行创建
          var _iterator = _createForOfIteratorHelper(required),
            _step;
          try {
            for (_iterator.s(); !(_step = _iterator.n()).done;) {
              var name = _step.value;
              if (properties && properties[name]) {
                result[name] = getDefaultValue(ctx, properties[name]);
              } else {
                return result;
              }
            }
          } catch (err) {
            _iterator.e(err);
          } finally {
            _iterator.f();
          }
        }
        return result;
      case 'array':
        var arrayResult = jsonDataType(nowData) === 'array' && items ? _.clone(nowData) : [];
        // 如果 items 是 arrayRefInfo，那么就是有前缀，覆写前缀
        if (prefixItems) {
          var ref = prefixItems.ref,
            length = prefixItems.length;
          for (var i = 0; i < length; i++) {
            arrayResult[i] = getDefaultValue(ctx, addRef(ref, i.toString()));
          }
        }
        return arrayResult;
      default:
        break;
    }
    return _.cloneDeep(defaultTypeValue[type]);
  } else {
    return null;
  }
};