function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
/* eslint-disable no-param-reassign */

import { getOfOption, getRefByOfChain } from "../context/ofInfo";
import { getFieldSchema } from "../utils/schemaWithRef";
import { jsonDataType } from "../utils/utils";
export var ShortLevel;

/**
 * 确定一个数据的**常量名称**。
 * 定义具体详见 [常量名称](https://gitee.com/furtherbank/json-schemaeditor-antd#常量名称)
 * @param v
 * @returns
 */
(function (ShortLevel) {
  ShortLevel[ShortLevel["no"] = 0] = "no";
  ShortLevel[ShortLevel["short"] = 1] = "short";
  ShortLevel[ShortLevel["extra"] = 2] = "extra";
})(ShortLevel || (ShortLevel = {}));
export var toConstName = function toConstName(v) {
  var t = jsonDataType(v);
  switch (t) {
    case 'object':
      return v.hasOwnProperty('name') ? v.name.toString() : "Object[".concat(Object.keys(v).length, "]");
    case 'array':
      return "Array[".concat(v.length, "]");
    case 'null':
      return 'null';
    // 注意 null 没有 toString
    default:
      return v.toString();
  }
};

/**
 * 确定一个模式在 of 选项中展示的**模式名称**。
 * 定义具体详见 [模式名称](https://gitee.com/furtherbank/json-schemaeditor-antd#模式名称)
 * @param mergedSchema 处理合并后的模式
 * @returns
 */
export var toOfName = function toOfName(mergedSchema) {
  var title = mergedSchema.title,
    type = mergedSchema.type;
  if (title) return title;
  if (type && type.length === 1) return type[0];
  return '';
};

/**
 * 得到当前 schemaEntry 下的 valueEntry 和 ofOption
 * @param data 当前数据
 * @param schemaEntry 当前数据的 schemaEntry
 * @param ctx 编辑器上下文对象
 * @returns
 */
export var getValueEntry = function getValueEntry(data, schemaEntry, ctx) {
  var valueEntry = undefined;
  var ofOption = null;
  if (schemaEntry) {
    // 确定 valueEntry
    ofOption = getOfOption(data, schemaEntry, ctx);
    valueEntry = ofOption === null ? schemaEntry : ofOption === false ? undefined : getRefByOfChain(ctx, schemaEntry, ofOption);
  }
  return {
    valueEntry: valueEntry,
    ofOption: ofOption
  };
};

/**
 * 得到当前数据通过 instancePath 继续查找得到的 schemaEntry
 * @param data 当然数据
 * @param path 继续的数据路径
 * @param ctx 编辑器上下文对象
 * @param curEntry 当前的 valueEntry，从这里开始查找
 */
export var getSchemaEntryByPath = function getSchemaEntryByPath(data, path, ctx) {
  var curEntry = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '#';
  var schemaEntry = curEntry;
  var nowData = data;
  while (path.length > 0) {
    var key = path.shift();
    var _getValueEntry = getValueEntry(data, schemaEntry, ctx),
      valueEntry = _getValueEntry.valueEntry;
    if (valueEntry === undefined) return undefined;
    var mergedValueSchema = ctx.getMergedSchema(valueEntry);
    console.assert(_typeof(nowData) === 'object');
    nowData = nowData[key];
    // 如果 getFieldEntry 得到 false，那就是一个指向 false 的 ref，直接当作 undefined
    schemaEntry = getFieldSchema(nowData, valueEntry, mergedValueSchema, key) || undefined;
    if (schemaEntry === undefined) return undefined;
  }
  return schemaEntry;
};