export declare const metaSchema: {
    title: string;
    definitions: {
        schemaArray: {
            type: string;
            title: string;
            minItems: number;
            items: {
                $ref: string;
            };
        };
        nonNegativeInteger: {
            type: string;
            minimum: number;
        };
        simpleTypes: {
            enum: string[];
        };
        stringArray: {
            type: string;
            items: {
                type: string;
            };
            uniqueItems: boolean;
            default: never[];
        };
        common: {
            type: string;
            properties: {
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
        };
        $ref: {
            type: string;
            title: string;
            properties: {
                $ref: {
                    description: string;
                    type: string;
                    format: string;
                };
                default: boolean;
                examples: {
                    type: string;
                };
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
            required: string[];
        };
        const: {
            type: string;
            title: string;
            properties: {
                const: {
                    description: string;
                    oneOf: {
                        type: string;
                    }[];
                };
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
            required: string[];
        };
        enum: {
            type: string;
            title: string;
            properties: {
                enum: {
                    type: string;
                    uniqueItems: boolean;
                };
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
            required: string[];
        };
        oneOf: {
            type: string;
            title: string;
            properties: {
                default: boolean;
                oneOf: {
                    $ref: string;
                };
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
            required: string[];
        };
        anyOf: {
            type: string;
            title: string;
            properties: {
                default: boolean;
                anyOf: {
                    $ref: string;
                };
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
            required: string[];
        };
        object: {
            type: string;
            title: string;
            properties: {
                type: {
                    const: string;
                };
                maxProperties: {
                    $ref: string;
                };
                minProperties: {
                    $ref: string;
                };
                required: {
                    $ref: string;
                };
                additionalProperties: {
                    $ref: string;
                };
                properties: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                    default: {};
                };
                patternProperties: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                    propertyNames: {
                        format: string;
                        type: string;
                    };
                    default: {};
                };
                dependencies: {
                    type: string;
                    additionalProperties: {
                        anyOf: {
                            $ref: string;
                        }[];
                    };
                };
                propertyNames: {
                    $ref: string;
                };
                not: {
                    $ref: string;
                };
                default: {
                    type: string;
                };
                examples: {
                    type: string;
                };
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
            required: string[];
            default: {
                type: string;
                properties: {};
                additionalProperties: boolean;
            };
        };
        array: {
            type: string;
            title: string;
            properties: {
                type: {
                    const: string;
                };
                additionalItems: {
                    $ref: string;
                };
                items: {
                    anyOf: {
                        $ref: string;
                    }[];
                };
                maxItems: {
                    $ref: string;
                };
                minItems: {
                    $ref: string;
                };
                uniqueItems: {
                    type: string;
                    default: boolean;
                };
                contains: {
                    $ref: string;
                };
                not: {
                    $ref: string;
                };
                default: {
                    type: string;
                };
                examples: {
                    type: string;
                };
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
            required: string[];
        };
        number: {
            type: string;
            title: string;
            properties: {
                type: {
                    enum: string[];
                };
                multipleOf: {
                    type: string;
                    exclusiveMinimum: number;
                };
                maximum: {
                    type: string;
                };
                exclusiveMaximum: {
                    type: string;
                };
                minimum: {
                    type: string;
                };
                exclusiveMinimum: {
                    type: string;
                };
                not: {
                    $ref: string;
                };
                default: {
                    type: string;
                };
                examples: {
                    type: string;
                };
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
            required: string[];
        };
        string: {
            type: string;
            title: string;
            properties: {
                type: {
                    const: string;
                };
                format: {
                    type: string;
                };
                pattern: {
                    type: string;
                    format: string;
                };
                maxLength: {
                    $ref: string;
                };
                minLength: {
                    $ref: string;
                };
                not: {
                    $ref: string;
                };
                default: {
                    type: string;
                };
                examples: {
                    type: string;
                };
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
            required: string[];
        };
        boolean: {
            type: string;
            title: string;
            properties: {
                type: {
                    const: string;
                };
                not: {
                    $ref: string;
                };
                default: {
                    type: string;
                    default: boolean;
                };
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
            required: string[];
        };
        null: {
            type: string;
            title: string;
            properties: {
                type: {
                    const: string;
                };
                $id: {
                    type: string;
                    format: string;
                };
                $schema: {
                    type: string;
                    format: string;
                };
                title: {
                    description: string;
                    type: string;
                };
                description: {
                    type: string;
                    description: string;
                    format: string;
                };
                definitions: {
                    type: string;
                    description: string;
                    additionalProperties: {
                        $ref: string;
                    };
                };
            };
            required: string[];
        };
        additional: {
            description: string;
            anyOf: ({
                title: string;
                type: string;
                $ref?: undefined;
            } | {
                $ref: string;
                title?: undefined;
                type?: undefined;
            })[];
        };
    };
    anyOf: ({
        title: string;
        type: string;
        $ref?: undefined;
    } | {
        $ref: string;
        title?: undefined;
        type?: undefined;
    })[];
};
