function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
/* eslint-disable no-case-declarations */
import clone from 'lodash/clone';
import { uri2strArray } from "./path/uri";
import { addRef, deepCollect, deepGet, getValueByPattern, jsonDataType } from "./utils";

/**
 * 找到 $ref 引用的 schemaMap。如果找不到返回一个空 Map
 * @param $ref json-pointer with #
 * @param rootSchema
 * @param deepSearch 深入搜索：深递归加入所有schema引用，否则只递归到浅一层
 * @returns
 */
export var getRefSchemaMap = function getRefSchemaMap($ref) {
  var rootSchema = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var deepSearch = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  var schemaMap = new Map();
  var refQueue = $ref instanceof Array ? clone($ref) : $ref ? [$ref] : [];
  while (refQueue.length > 0) {
    var nowRef = addRef(refQueue.shift());
    var current = deepGet(rootSchema, uri2strArray(nowRef));
    if (current !== undefined) {
      schemaMap.set(nowRef, current);
      if (deepSearch) {
        var refs = deepCollect(current, '$ref');
        if (refs instanceof Array) {
          var _iterator = _createForOfIteratorHelper(refs),
            _step;
          try {
            for (_iterator.s(); !(_step = _iterator.n()).done;) {
              var ref = _step.value;
              if (typeof ref === 'string' && !schemaMap.has(addRef(ref))) refQueue.push(ref);
            }
          } catch (err) {
            _iterator.e(err);
          } finally {
            _iterator.f();
          }
        }
      } else {
        if (current.hasOwnProperty('$ref') && !schemaMap.has(addRef(current.$ref))) {
          refQueue.push(current.$ref);
        }
      }
    }
  }
  return schemaMap;
};

/**
 * 找到 schemaMap 中所有含有某键的 uri 引用
 * @param schemaMap
 * @param k
 * @param all 是否拿到所有 ref ，默认只拿第一个
 * @param add 返回的ref是否加入属性名称，默认加入
 * @returns
 */
// export const findKeyRefs = (schemaMap: Map<string, any>, k: string, all = false, add = true) => {
//   const allRefs = []
//   for (const [ref, schema] of schemaMap) {
//     if (schema instanceof Object && schema[k] !== undefined) {
//       if (all) {
//         allRefs.push(add ? addRef(ref, k)! : ref)
//       } else {
//         return add ? addRef(ref, k)! : ref
//       }
//     }
//   }
//   return all ? allRefs : undefined
// }

/**
 * 对 Array/Object 获取特定字段 schemaEntry。
 * 注意：
 * 1. 无论这其中有多少条 ref，一定保证给出的 schemaEntry 是从 `properties, patternProperties, additionalProperties, prefixItems, items` 这五个字段之一进入的。
 * 2. 只要给出的 ref 不是 undefined，一定能够找到对应的 schema
 * @param data 当前的 data
 * @param valueEntry
 * @param mergedValueSchema
 * @param field
 * @returns 对应子字段的 schemaEntry，结果为 false 代表对应 schema 为 false，在模式支持上当作 undefined 处理即可
 */
export var getFieldSchema = function getFieldSchema(data, valueEntry, mergedValueSchema, field) {
  if (!mergedValueSchema) return undefined;
  var properties = mergedValueSchema.properties,
    patternProperties = mergedValueSchema.patternProperties,
    additionalProperties = mergedValueSchema.additionalProperties,
    items = mergedValueSchema.items,
    prefixItems = mergedValueSchema.prefixItems;
  var dataType = jsonDataType(data);
  switch (dataType) {
    case 'object':
      if (properties && properties[field]) return properties[field];
      if (patternProperties) {
        var ref = getValueByPattern(patternProperties, field);
        if (ref) return ref;
      }
      if (additionalProperties !== undefined) return additionalProperties;
      // 如果上面这些属性都没有但是 type = object，会使得这里到了下面的 case 而出错
      return undefined;
    case 'array':
      /**
       * 注意：draft 2020-12 调整了items，删除了additionalItems属性。
       * 个人认为这么做是正确的，但是旧的没改，还需要兼容
       * 详情见：https://json-schema.org/draft/2020-12/release-notes.html
       */
      var index = parseInt(field, 10);
      if (isNaN(index) || index < 0) {
        throw new Error("\u83B7\u53D6\u5B57\u6BB5\u6A21\u5F0F\u9519\u8BEF\uFF1A\u5728\u6570\u7EC4\u4E2D\u83B7\u53D6\u975E\u6CD5\u7D22\u5F15 ".concat(field, "\n\u8F85\u52A9\u4FE1\u606F\uFF1A").concat(valueEntry, " \n ").concat(JSON.stringify(mergedValueSchema, null, 2)));
      }
      if (prefixItems) {
        var length = prefixItems.length,
          _ref = prefixItems.ref;
        if (index < length) {
          return addRef(_ref, field);
        } else {
          return items;
        }
      } else if (items) {
        return items;
      } else {
        return undefined;
      }
    default:
      throw new Error("\u83B7\u53D6\u5B57\u6BB5\u6A21\u5F0F\u9519\u8BEF\uFF1A\u5728\u975E\u5BF9\u8C61\u4E2D\u83B7\u53D6\u5B57\u6BB5\u6A21\u5F0F ".concat(field, "\n\u8F85\u52A9\u4FE1\u606F\uFF1A").concat(valueEntry, " \n ").concat(JSON.stringify(mergedValueSchema, null, 2)));
  }
};